@@ -1,11 +1,10 @@
 #' This function creates a summarized experiment object from count
 #' and metadata files uploaded by the user
-#' @param counts counts dataframe
+#' @param counts counts matrix
 #' @param columndata metadata dataframe
 #' @return a summarized experiment object
 #' @import SummarizedExperiment
 #' @import reader
-#' @import EBSeq
 #' @import utils
 #'
 #' @examples
@@ -22,7 +21,7 @@ summarized_experiment <- function(counts, columndata) {
     counts <- counts[, mutual_sample]
     columndata <- columndata[mutual_sample, ]
 
-    se <- SummarizedExperiment(assays = list(counts = counts),
+    se <- SummarizedExperiment(assays = list(features = counts),
                                 colData = columndata,
                                 metadata = list(metadata = columndata))
     se <- se[which(rownames(se) != 'NA')]
